==> pgbackrest_2.16.orig.tar.gz: pgbackrest-release-2.16/src/db/helper.h <==
/***********************************************************************************************************************************
Database Helper

Helper functions for getting connections to PostgreSQL.
***********************************************************************************************************************************/
#ifndef DB_HELPER_H
#define DB_HELPER_H

#include <stdbool.h>

#include "db/db.h"

/***********************************************************************************************************************************
Functions
***********************************************************************************************************************************/
typedef struct DbGetResult
{
    unsigned int primaryId;
    Db *primary;
    unsigned int standbyId;
    Db *standby;
} DbGetResult;

DbGetResult dbGet(bool primaryOnly, bool primaryRequired);

/***********************************************************************************************************************************
Macros for function logging
***********************************************************************************************************************************/
#define FUNCTION_LOG_DB_GET_RESULT_TYPE                                                                                            \
    DbGetResult
#define FUNCTION_LOG_DB_GET_RESULT_FORMAT(value, buffer, bufferSize)                                                               \
    objToLog(&value, "DbGetResult", buffer, bufferSize)

#endif

==> pgbackrest_2.24.orig.tar.gz: pgbackrest-release-2.24/src/db/helper.h <==
/***********************************************************************************************************************************
Database Helper

Helper functions for getting connections to PostgreSQL.
***********************************************************************************************************************************/
#ifndef DB_HELPER_H
#define DB_HELPER_H

#include <stdbool.h>

#include "db/db.h"

/***********************************************************************************************************************************
Functions
***********************************************************************************************************************************/
typedef struct DbGetResult
{
    unsigned int primaryId;
    Db *primary;
    unsigned int standbyId;
    Db *standby;
} DbGetResult;

DbGetResult dbGet(bool primaryOnly, bool primaryRequired, bool standbyRequired);

/***********************************************************************************************************************************
Macros for function logging
***********************************************************************************************************************************/
#define FUNCTION_LOG_DB_GET_RESULT_TYPE                                                                                            \
    DbGetResult
#define FUNCTION_LOG_DB_GET_RESULT_FORMAT(value, buffer, bufferSize)                                                               \
    objToLog(&value, "DbGetResult", buffer, bufferSize)

#endif
